@@ -179,16 +179,16 @@ class Service(object):
     QUERY_PATH             = '/query/results'
     LIST_ENRICHMENT_PATH   = '/list/enrichment'
     WIDGETS_PATH           = '/widgets'
-    QUERY_LIST_UPLOAD_PATH = '/query/tolist/json'
-    QUERY_LIST_APPEND_PATH = '/query/append/tolist/json'
+    QUERY_LIST_UPLOAD_PATH = '/query/tolist'
+    QUERY_LIST_APPEND_PATH = '/query/append/tolist'
     MODEL_PATH             = '/model'
     TEMPLATES_PATH         = '/templates/xml'
     TEMPLATEQUERY_PATH     = '/template/results'
-    LIST_PATH              = '/lists/json'
-    LIST_CREATION_PATH     = '/lists/json'
-    LIST_RENAME_PATH       = '/lists/rename/json'
-    LIST_APPENDING_PATH    = '/lists/append/json'
-    LIST_TAG_PATH          = '/list/tags/json'
+    LIST_PATH              = '/lists'
+    LIST_CREATION_PATH     = '/lists'
+    LIST_RENAME_PATH       = '/lists/rename'
+    LIST_APPENDING_PATH    = '/lists/append'
+    LIST_TAG_PATH          = '/list/tags'
     SAVEDQUERY_PATH        = '/savedqueries/xml'
     VERSION_PATH           = '/version/ws'
     RELEASE_PATH           = '/version/release'
